<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleT2P</name>
    <message>
        <location filename="../CircleT2P.js" line="+75"/>
        <source>Line, arc or circle</source>
        <translation>Linia, łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>First point on circle line</source>
        <translation>Pierwszy punkt na okręgu</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second point on circle line</source>
        <translation>Drugi punkt na okręgu</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>Proszę wskazać rozwiązanie</translation>
    </message>
    <message>
        <location line="+134"/>
        <location line="+48"/>
        <source>No solution</source>
        <translation>Brak rozwiązania</translation>
    </message>
    <message>
        <location filename="../CircleT2PInit.js" line="+2"/>
        <source>&amp;Tangent and 2 Points</source>
        <translation>&amp;Styczny przez 2 punkty</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle through two points and tangential to one entity</source>
        <translation>Rysuje okrąg przez dwa punkty, styczny do jednego elementu</translation>
    </message>
</context>
</TS>
